#
# spec file for package dpic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dpic
Version:        2024.01.01
Release:        1.2
Summary:        Pic language processor
License:        BSD-2-Clause AND CC-BY-3.0
Group:          Productivity/Publishing/Other
URL:            https://ece.uwaterloo.ca/~aplevich/dpic/
Source0:        https://ece.uwaterloo.ca/~aplevich/dpic/%{name}-%{version}.tar.gz

%description
Pic language processor for LaTeX documents or web sites.

%package        doc
Summary:        Documentation for dpic
Group:          Documentation/Other
Requires:       dpic
BuildArch:      noarch

%description    doc

This package contains the documentation for dpic.

%prep
%setup -q -n %{name}-%{version}

%build
%configure \
    --docdir=%{_docdir}/%{name}

make %{?_smp_mflags}

%install
%make_install PREFIX=%{_prefix} DOCDIR=%{buildroot}%{_docdir}/%{name}

%files
%license Copyright.txt
%doc README CHANGES
%exclude %{_docdir}/dpic/dpic-doc.pdf
%exclude %{_docdir}/dpic/dpictools.pic
%{_bindir}/%{name}
%{_mandir}/man1/dpic.1*

%files doc
%{_docdir}/dpic/dpic-doc.pdf
%{_docdir}/dpic/dpictools.pic

%changelog
* Tue Jul  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.01.01:
  * SVG stroke fix.
  * Robust arrowheads and pgf text offsets.
* Fri Mar  3 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.02.1:
  * More precise obtuse-angle arcs.
  * Minor addition to the manual.
  * Non-LaTeX error-handling cleanup.
  * Line thickness recovery parameter enabled.
  * Redundant code dating from pascal conversion removed.
  * Robustness fixes.
  * Improved robustness for fuzzed input.
  * Added colored svg sprintf text and %% appended to selected outputs.
  * Shift operation bugfix.
  * Improved error messaging; additional distribution examples.
  * CVE-2021-33390: Use-after-free in thedeletestringbox() (boo#1214501).
  * CVE-2021-33388: Heap Buffer Overflow in themakevar() (boo#1214502).
  * CVE-2021-32422: Buffer Overflow in theyylex() (boo#1214503).
  * CVE-2021-32421: Heap Use-After-Free in thedeletestringbox() (boo#1214504).
  * CVE-2021-32420: Heap-based Buffer Overflow in thestorestring() (boo#1214505).
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2020.06.01:
  * SVG text adjustments; GCC-10 conformance.
  * Commas protected by brackets; zero-repetition "for" loop bugfix
    under bison.
  * Fix of environment variable scope, arc attribute; improved error
    messages; generalized macro definition.
  * Corrected typos, copyright notices, version number, string treatment.
  * Bugfix for buffer overflow with extreme arguments of wfloat().
  * This is a major clone of the previous distribution, which
  contained compilable C code together with the original pascal
  source.  The pascal was translated to C code using p2c,
  which was included, and parsing was automated by a custom
  compiler-compiler which was also provided.  The current
  package includes C source only with parsing automated using
  GNU bison.  The original lexical analyser has been kept. To
  avoid introducing bugs, the C code has been changed only to
  accommodate bison; some p2c idiosyncrasies remain. The result
  is functionally identical to the previous version for correct
  input.
* Wed Aug 23 2017 dmitry_r@opensuse.org
- Update to version 2017.08.01
  * Minor changes and bugfixes
* Thu Aug 13 2015 dmitry_r@opensuse.org
- Update to version 2015.06.29
  * Fixed a bug in svg output.
  * Undeferred error messaging. Improved readability of C code.
* Wed May 20 2015 dmitry_r@opensuse.org
- Update to version 2015.05.19
  * Bugfixes for nested if-statement and multiple pdf strings.
  * Fix comment lines containing braces in macro and for bodies.
    Revised messages for some errors.
* Wed Feb 25 2015 dmitry_r@opensuse.org
- Update to version 2015.02.16
  * Reworked the handling of backslashes in strings in macro arguments.
  * PDF output. Built-in variable dpicopt and variables added for
    detecting command options. Linear objects reworked for
    consistent fill.
* Tue Jan 14 2014 dmitry_r@opensuse.org
- Update to version 2014.01.01
  * Input lines of arbitrary length and line continuation (except
    in strings).  Object parameters .thick = .thickness and .len =
    .length, eg t=last box.thick; q = last line.len
* Sat Oct  5 2013 dmitry_r@opensuse.org
- Update to version 2013.09.30
  * Better portability of the random() function
* Mon Mar 11 2013 dmitry_r@opensuse.org
- update to version 2013.03.10
  * Minor tweak to svg output
* Sat Nov 24 2012 dmitry_r@opensuse.org
- update to version 2012.11.04
  * Change to always send errors to /dev/stderr
* Thu Sep  6 2012 cfarrell@suse.com
- license update: BSD-2-Clause and CC-BY-3.0
  dpicdoc.pdf is CC-BY-3.0 licensed according to dpic/README
* Thu Aug 16 2012 dmitry_r@opensuse.org
- separate dpic-doc package
- using %%optflags for build
* Mon Jul 16 2012 dmitry_r@opensuse.org
- update to version 2012.07.14
  * Fixed the previous fix to handle planar objects correctly
* Sun Jun 24 2012 dmitry_r@opensuse.org
- update to version 2012.06.20
  * Give line attributes the same effect for pgf and pstricks ouput
* Sat Jun  2 2012 dmitry_r@opensuse.org
- update to version 2012.05.29
  * Error message for zero second argument to pmod(,)
* Fri Feb 17 2012 dmitry_r@opensuse.org
- update to version 2012.02.12
  * Fixed a mishandling of null macro arguments in loops.
* Thu Dec  8 2011 dmitry_r@opensuse.org
- update to version 2011.12.06
  * changes in documents
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Sep 23 2011 dmitry_r@opensuse.org
- update to version 2011.07.11
  * changes in documents
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Jun 16 2011 dmitry_r@opensuse.org
- update to version 2011.06.05
  * changes in documents
* Fri Mar 18 2011 dmitry_r@opensuse.org
- update to version 2011.03.17
  * Compile #elif for OpenBSD
* Sat Jan  1 2011 dmitry_r@opensuse.org
- update to version 2010.12.30
  * Reworked for loops to allow assignment to the loop variable.
* Thu Dec  9 2010 dmitry_r@opensuse.org
- initial package
- version 2010.12.08
